@@ -27,7 +27,7 @@ except NameError:
 
 @not_implemented_for('undirected')
 def network_simplex(G, demand='demand', capacity='capacity', weight='weight'):
-    """Find a minimum cost flow satisfying all demands in digraph G.
+    r"""Find a minimum cost flow satisfying all demands in digraph G.
 
     This is a primal network simplex algorithm that uses the leaving
     arc rule to prevent cycling.
@@ -45,7 +45,7 @@ def network_simplex(G, demand='demand', capacity='capacity', weight='weight'):
         DiGraph on which a minimum cost flow satisfying all demands is
         to be found.
 
-    demand: string
+    demand : string
         Nodes of the graph G are expected to have an attribute demand
         that indicates how much flow a node wants to send (negative
         demand) or receive (positive demand). Note that the sum of the
@@ -53,13 +53,13 @@ def network_simplex(G, demand='demand', capacity='capacity', weight='weight'):
         this attribute is not present, a node is considered to have 0
         demand. Default value: 'demand'.
 
-    capacity: string
+    capacity : string
         Edges of the graph G are expected to have an attribute capacity
         that indicates how much flow the edge can support. If this
         attribute is not present, the edge is considered to have
         infinite capacity. Default value: 'capacity'.
 
-    weight: string
+    weight : string
         Edges of the graph G are expected to have an attribute weight
         that indicates the cost incurred by sending one unit of flow on
         that edge. If not present, the weight is considered to be 0.
@@ -67,10 +67,10 @@ def network_simplex(G, demand='demand', capacity='capacity', weight='weight'):
 
     Returns
     -------
-    flowCost: integer, float
+    flowCost : integer, float
         Cost of a minimum cost flow satisfying all demands.
 
-    flowDict: dictionary
+    flowDict : dictionary
         Dictionary of dictionaries keyed by nodes such that
         flowDict[u][v] is the flow edge (u, v).
 
@@ -82,6 +82,7 @@ def network_simplex(G, demand='demand', capacity='capacity', weight='weight'):
 
     NetworkXUnfeasible
         This exception is raised in the following situations:
+
             * The sum of the demands is not zero. Then, there is no
               flow satisfying all demands.
             * There is no flow satisfying all demand.
@@ -93,9 +94,11 @@ def network_simplex(G, demand='demand', capacity='capacity', weight='weight'):
 
     Notes
     -----
-    This algorithm is not guaranteed to work if edge weights
+    This algorithm is not guaranteed to work if edge weights or demands
     are floating point numbers (overflows and roundoff errors can
-    cause problems).
+    cause problems). As a workaround you can use integer numbers by
+    multiplying the relevant edge attributes by a convenient
+    constant factor (eg 100).
 
     See also
     --------
@@ -189,7 +192,7 @@ def network_simplex(G, demand='demand', capacity='capacity', weight='weight'):
 
     N = list(G)                                # nodes
     I = {u: i for i, u in enumerate(N)}        # node indices
-    D = [G.node[u].get(demand, 0) for u in N]  # node demands
+    D = [G.nodes[u].get(demand, 0) for u in N]  # node demands
 
     inf = float('inf')
     for p, b in zip(N, D):
@@ -206,9 +209,9 @@ def network_simplex(G, demand='demand', capacity='capacity', weight='weight'):
     C = []  # edge weights
 
     if not multigraph:
-        edges = G.edges_iter(data=True)
+        edges = G.edges(data=True)
     else:
-        edges = G.edges_iter(data=True, keys=True)
+        edges = G.edges(data=True, keys=True)
     edges = (e for e in edges
              if e[0] != e[1] and e[-1].get(capacity, inf) != 0)
     for i, e in enumerate(edges):
@@ -224,9 +227,9 @@ def network_simplex(G, demand='demand', capacity='capacity', weight='weight'):
         if abs(c) == inf:
             raise nx.NetworkXError('edge %r has infinite weight' % (e,))
     if not multigraph:
-        edges = G.selfloop_edges(data=True)
+        edges = nx.selfloop_edges(G, data=True)
     else:
-        edges = G.selfloop_edges(data=True, keys=True)
+        edges = nx.selfloop_edges(G, data=True, keys=True)
     for e in edges:
         if abs(e[-1].get(weight, 0)) == inf:
             raise nx.NetworkXError('edge %r has infinite weight' % (e[:-1],))
@@ -241,16 +244,16 @@ def network_simplex(G, demand='demand', capacity='capacity', weight='weight'):
         if u < 0:
             raise nx.NetworkXUnfeasible('edge %r has negative capacity' % (e,))
     if not multigraph:
-        edges = G.selfloop_edges(data=True)
+        edges = nx.selfloop_edges(G, data=True)
     else:
-        edges = G.selfloop_edges(data=True, keys=True)
+        edges = nx.selfloop_edges(G, data=True, keys=True)
     for e in edges:
         if e[-1].get(capacity, inf) < 0:
             raise nx.NetworkXUnfeasible(
                 'edge %r has negative capacity' % (e[:-1],))
 
     ###########################################################################
-    # Initialization 
+    # Initialization
     ###########################################################################
 
     # Add a dummy node -1 and connect all existing nodes to it with infinite-
@@ -281,7 +284,7 @@ def network_simplex(G, demand='demand', capacity='capacity', weight='weight'):
     parent = list(chain(repeat(-1, n), [None]))  # parent nodes
     edge = list(range(e, e + n))                 # edges to parents
     size = list(chain(repeat(1, n), [n + 1]))    # subtree sizes
-    next = list(chain(range(1, n), [-1, 0]))     # next nodes in depth-first thread 
+    next = list(chain(range(1, n), [-1, 0]))     # next nodes in depth-first thread
     prev = list(range(-1, n))                    # previous nodes in depth-first thread
     last = list(chain(range(n), [n - 1]))        # last descendants in depth-first thread
 
@@ -544,7 +547,7 @@ def network_simplex(G, demand='demand', capacity='capacity', weight='weight'):
 
     if (any(x[i] * 2 >= faux_inf for i in range(e)) or
         any(e[-1].get(capacity, inf) == inf and e[-1].get(weight, 0) < 0
-            for e in G.selfloop_edges(data=True))):
+            for e in nx.selfloop_edges(G, data=True))):
         raise nx.NetworkXUnbounded(
             'negative cycle with infinite capacity found')
 
@@ -574,11 +577,11 @@ def network_simplex(G, demand='demand', capacity='capacity', weight='weight'):
     if not multigraph:
         for e in zip(S, T, x):
             add_entry(e)
-        edges = G.edges_iter(data=True)
+        edges = G.edges(data=True)
     else:
         for e in zip(S, T, K, x):
             add_entry(e)
-        edges = G.edges_iter(data=True, keys=True)
+        edges = G.edges(data=True, keys=True)
     for e in edges:
         if e[0] != e[1]:
             if e[-1].get(capacity, inf) == 0:
