@@ -7,18 +7,18 @@ Do not add this file to the repository.
 
 import datetime
 
-version = '1.11'
-date = 'Sat Jan  7 07:55:16 2017'
+version = '2.0'
+date = 'Fri Sep 29 22:03:34 2017'
 
 # Was NetworkX built from a development version? If so, remember that the major
 # and minor versions reference the "target" (rather than "current") release.
 dev = False
 
 # Format: (name, major, min, revision)
-version_info = ('networkx', '1', '11', None)
+version_info = ('networkx', '2', '0', None)
 
 # Format: a 'datetime.datetime' instance
-date_info = datetime.datetime(2017, 1, 7, 7, 55, 16, 417107)
+date_info = datetime.datetime(2017, 9, 29, 22, 3, 34, 984929)
 
 # Format: (vcs, vcs_tuple)
 vcs_info = (None, (None, None))
