@@ -1,15 +1,18 @@
 #!/usr/bin/env python
 """
+=====================
+Pygraphviz Attributes
+=====================
+
 An example showing how to use the interface to the pygraphviz
 AGraph class to convert to and from graphviz.
 
 Also see the pygraphviz documentation and examples at
 http://pygraphviz.github.io/
-
 """
 # Author: Aric Hagberg (hagberg@lanl.gov)
 
-#    Copyright (C) 2006-2016 by
+#    Copyright (C) 2006-2017 by
 #    Aric Hagberg <hagberg@lanl.gov>
 #    Dan Schult <dschult@colgate.edu>
 #    Pieter Swart <swart@lanl.gov>
@@ -37,7 +40,7 @@ A.write('k5_attributes.dot')
 # default attributes as dictionary data
 X = nx.nx_agraph.from_agraph(A)
 print("edges")
-print(X.edges(data=True))
+print(list(X.edges(data=True)))
 print("default graph attributes")
 print(X.graph)
 print("node node attributes")
